@@ -70,7 +70,7 @@ class SOFTextExtractor:
         {
             "name": 'dd-mmmm-yyyy',
             "mask": "%d/%m/%Y",
-            "regex": '((31(?!\-(FEB|Feb(ruary)?|APR|Apr(il)?|JUN|June?|(SEP|Sep(?=\b|t)t?|NOV|Nov)(ember)?)))|((30|29)(?!\-FEB|Feb(ruary)?))|(29(?=\-FEB|Feb(ruary)?\-(((1[6-9]|[2-9]\d)(0[48]|[2468][048]|[13579][26])|((16|[2468][048]|[3579][26])00)))))|(0?[1-9])|1\d|2[0-8])\-(JAN|Jan(uary)?|FEB|Feb(ruary)?|MAR|Ma(r(ch)?|y)|APR|Apr(il)?|JUL|Ju((ly?)|(ne?))|AUG|Aug(ust)?|OCT|Oct(ober)?|(SEP|Sep(?=\b|t)t?|NOV|Nov|DEC|Dec)(ember)?)\-((1[6-9]|[2-9]\d)\d{2})',
+            "regex": '((31(?!\-(feb(ruary)?|apr(il)?|june?|(sep(?=\b|t)t?|nov)(ember)?)))|((30|29)(?!\-feb(ruary)?))|(29(?=\-feb(ruary)?\-(((1[6-9]|[2-9]\d)(0[48]|[2468][048]|[13579][26])|((16|[2468][048]|[3579][26])00)))))|(0?[1-9])|1\d|2[0-8])\-(jan(uary)?|feb(ruary)?|ma(r(ch)?|y)|apr(il)?|ju((ly?)|(ne?))|aug(ust)?|oct(ober)?|(sep(?=\b|t)t?|nov|dec)(ember)?)\-((1[6-9]|[2-9]\d)\d{2})',
             "delimiter": '-',
             "function":"date_parse",
             "type" : "dmy"
@@ -79,7 +79,7 @@ class SOFTextExtractor:
         {
             "name": 'dd/mmmm/yyyy',
             "mask": "%d/%m/%Y",
-            "regex": '((31(?!\/(FEB|Feb(ruary)?|APR|Apr(il)?|JUN|June?|(SEP|Sep(?=\b|t)t?|NOV|Nov)(ember)?)))|((30|29)(?!\/FEB|Feb(ruary)?))|(29(?=\/FEB|Feb(ruary)?\/(((1[6-9]|[2-9]\d)(0[48]|[2468][048]|[13579][26])|((16|[2468][048]|[3579][26])00)))))|(0?[1-9])|1\d|2[0-8])\/(JAN|Jan(uary)?|FEB|Feb(ruary)?|MAR|Ma(r(ch)?|y)|APR|Apr(il)?|JUL|Ju((ly?)|(ne?))|AUG|Aug(ust)?|OCT|Oct(ober)?|(SEP|Sep(?=\b|t)t?|NOV|Nov|DEC|Dec)(ember)?)\/((1[6-9]|[2-9]\d)\d{2})',
+            "regex": '((31(?!\/(feb(ruary)?|apr(il)?|june?|(sep(?=\b|t)t?|nov)(ember)?)))|((30|29)(?!\/feb(ruary)?))|(29(?=\/feb(ruary)?\/(((1[6-9]|[2-9]\d)(0[48]|[2468][048]|[13579][26])|((16|[2468][048]|[3579][26])00)))))|(0?[1-9])|1\d|2[0-8])\/(jan(uary)?|feb(ruary)?|ma(r(ch)?|y)|apr(il)?|ju((ly?)|(ne?))|aug(ust)?|oct(ober)?|(sep(?=\b|t)t?|nov|dec)(ember)?)\/((1[6-9]|[2-9]\d)\d{2})',
             "delimiter": '/',
             "function":"date_parse",
             "type" : "dmy"
@@ -89,7 +89,7 @@ class SOFTextExtractor:
         {
             "name": 'dd mmmm yyyy',
             "mask": "%d/%m/%Y",
-            "regex": '((31(?!\ (FEB|Feb(ruary)?|APR|Apr(il)?|JUN|June?|(SEP|Sep(?=\b|t)t?|NOV|Nov)(ember)?)))|((30|29)(?!\ FEB|Feb(ruary)?))|(29(?=\ FEB|Feb(ruary)?\ (((1[6-9]|[2-9]\d)(0[48]|[2468][048]|[13579][26])|((16|[2468][048]|[3579][26])00)))))|(0?[1-9])|1\d|2[0-8])\ (JAN|Jan(uary)?|FEB|Feb(ruary)?|MAR|Ma(r(ch)?|y)|APR|Apr(il)?|JUL|Ju((ly?)|(ne?))|AUG|Aug(ust)?|OCT|Oct(ober)?|(SEP|Sep(?=\b|t)t?|NOV|Nov|DEC|Dec)(ember)?)\ ((1[6-9]|[2-9]\d)\d{2})',
+            "regex": '((31(?!\ (feb(ruary)?|apr(il)?|june?|(sep(?=\b|t)t?|nov)(ember)?)))|((30|29)(?!\ feb(ruary)?))|(29(?=\ feb(ruary)?\ (((1[6-9]|[2-9]\d)(0[48]|[2468][048]|[13579][26])|((16|[2468][048]|[3579][26])00)))))|(0?[1-9])|1\d|2[0-8])\ (jan(uary)?|feb(ruary)?|ma(r(ch)?|y)|apr(il)?|ju((ly?)|(ne?))|aug(ust)?|oct(ober)?|(sep(?=\b|t)t?|nov|dec)(ember)?)\ ((1[6-9]|[2-9]\d)\d{2})',
             "delimiter": ' ',
             "function":"date_parse",
             "type" : "dmy"
@@ -99,7 +99,7 @@ class SOFTextExtractor:
 
             "name": 'mmmm dd yyyy',
             "mask": "%m/%d/%Y",
-            "regex" : "(JAN|Jan|January|FEB|Feb|February|MAR|Mar|March|APR|Apr|April|MAY|May|JUN|Jun|June|JUL|Jul|July|AUG|Aug|August|SEP|Sep|September|OCT|Oct|October|NOV|Nov|November|DEC|Dec|December)[^A-Za-z0-9]+([1-9]|[1-3][0-9])[^A-Za-z0-9]+\d{4}",
+            "regex" : "(jan|january|feb|february|mar|march|apr|april|may|jun|june|jul|july|aug|august|sep|september|oct|october|nov|november|dec|december)[^A-Za-z0-9]+([1-9]|[1-3][0-9])[^A-Za-z0-9]+\d{4}",
             "delimiter" : "[^A-Za-z0-9]+",
             "function":"date_parse",
             "type":"mdy"    
@@ -107,13 +107,23 @@ class SOFTextExtractor:
 
         {
 
-            "name": 'dd mmmm yyyy',
-            "mask": "%m/%d/%Y",
-            "regex" : "([1-9]|[1-3][0-9])[^A-Za-z0-9]+(JAN|Jan|January|FEB|Feb|February|MAR|Mar|March|APR|Apr|April|MAY|May|JUN|Jun|June|JUL|Jul|July|AUG|Aug|August|SEP|Sep|September|OCT|Oct|October|NOV|Nov|November|DEC|Dec|December)[^A-Za-z0-9]+\d{4}",
-            "delimiter" : "[^A-Za-z0-9]+",
-            "function":"date_parse",
+            "name": 'dd?mm?yyyy',
+            "mask": "%d/%m/%Y",
+            "regex" : "(0?[1-9]|[12][0-9]|3[01])[\/\-\.](0?[1-9]|1[012])[\/\-\.]\d{4}",
+            "delimiter" : "[\/\-\.]",
+            "function":"num_date_parse",
             "type":"dmy"    
-        } 
+        },
+
+        {
+
+            "name": 'mm?dd?yyyy',
+            "mask": "%d/%m/%Y",
+            "regex" : "(0?[1-9]|1[012])[\.](0?[1-9]|[12][0-9]|3[01])[\.]\d{4}",
+            "delimiter" : "[\/\-\.]",
+            "function":"num_date_parse",
+            "type":"mdy"    
+        }
 
     ]
 
@@ -165,7 +175,8 @@ class SOFTextExtractor:
         pass
 
     def extract(self, text, starttext=None, endtext=None, startdate=None, enddate=None, dateorder=None, timemask="hh:mm", tz=timezone.utc):
-        sofs = []
+        sofs = SOF(id = str(uuid4()))
+        full_sofs = []
         summary_sofs = []
         date_count = startdate
         lines = text.splitlines()
@@ -174,49 +185,65 @@ class SOFTextExtractor:
         else:
             started = True
         for line in lines:
-            if started and self.textContainsSof(line):
-                sof= self.extractLine(line, date_count, dateorder, timemask, tz)
+            text = line.lower()
+            if started and self.textContainsSof(text):
+                sof= self.extractLine(text, date_count, dateorder, timemask, tz)
                 if sof.startdatetime:
                     date_count = sof.startdatetime
-                sofs.append(sof) if sof not in sofs else sofs
+                full_sofs.append(sof) if sof not in full_sofs else sofs
                 if next((x for x in self.soflist.softypes if x.id == sof.id and x.summary), None):
-                    summary_sofs.append(sof)
-            elif started and self.extractDate(line,dateorder):
-                date_count = self.extractDate(line,dateorder)[0]
+                    summary_sofs.append(sof) if sof not in summary_sofs else summary_sofs
+            elif started and self.extractDate(text,dateorder):
+                date_count = self.extractDate(text,dateorder)[0]['fulldate']
             else:
-                if starttext and starttext in line:
+                if starttext and starttext.lower() in text:
                     print("started reading")
                     started = True
+        sofs.sofs = full_sofs
+        sofs.summary_sofs = summary_sofs
         return sofs
                     
 
                 
 
     def extractLine(self, text, date_count, dateorder, timemask, tz=timezone.utc):
-
+        text = text.lower()
         restext = text
         softype = self.textContainsSof(text)
-        id = SHC + str(uuid4())
+        id = str(uuid4())
         sof = SOFEvent(id, softype.id, softype.description)
-        times = self.extractTime(text, timemask)
+        if softype.summary:
+            sof.summary = True
+        
         time_from = None
         time_to = None
         date_from = None
         date_to = None
+
+        timetext = text
+
+        dates = self.extractDate(text, dateorder)
+        if dates:
+            date_from = dates[0]['fulldate']
+            date_to = None
+            if len(dates) > 1:
+
+                timetext = timetext.replace(dates[1]['datestring'], "")
+                date_to = dates[1]['fulldate']
+        else:
+            date_from = date_count
+            date_to = None
+
+
+
+        times = self.extractTime(timetext, timemask)
         if times:
             time_from = times[0]
             time_to = None
             if softype.bounded and len(times) > 1:
-                time_to = times[1]
-        dates = self.extractDate(text, dateorder)
-        if dates:
-            date_from = dates[0]
-            date_to = None
-            if len(dates) > 1:
-                date_to = dates[1]
-        else:
-            date_from = date_count
-            date_to = None
+
+                time_to = times[1]        
+
         if (times and not dates) and (softype.bounded and time_to) and (time_to < time_from):
             date_to = date_count + datetime.timedelta(days=1)
         if not time_from:
@@ -232,7 +259,7 @@ class SOFTextExtractor:
     def textContainsSof(self, text):
         res = False
         for sof in self.soflist.softypes:
-            if sof.description in text:
+            if sof.description.lower() in text:
                 return sof
         return res
 
@@ -278,19 +305,21 @@ class SOFTextExtractor:
 
     def extractDate(self, text, dateorder):
         res = None
-        
+        text = text.lower()
         if dateorder:
             dates =  search_dates(text, settings={'DATE_ORDER': dateorder, 'RELATIVE_BASE': datetime.datetime(1925, 1, 1)})
         else:
             dates =  search_dates(text, settings={'RELATIVE_BASE': datetime.datetime(1925, 1, 1)})
         if dates and len(dates) > 0:
             for adate in dates:
+               
                 delimiters = list(filter(self.checkDelim, re.split("[a-zA-Z0-9]+", adate[0])))
 
                 if  adate[1].year > 1970 and not (self.containsTime(adate[0])) and len(delimiters) == 2 and (delimiters[0] == delimiters[1]):
+                    
                     if not res:
                         res = []
-                    res.append(adate[1])   
+                    res.append({'datestring': adate[0], 'fulldate':adate[1]})   
 
         if not res:
             for datepattern in self.datepatterns:
@@ -301,7 +330,7 @@ class SOFTextExtractor:
                     mth = getattr(self, datepattern['function'])
                     for pattern in patternres:
                         if pattern and len(re.split('[^a-zA-Z0-9]+', pattern)) > 2:
-                            res.append(mth(pattern,datepattern))
+                            res.append({'datestring':pattern, 'fulldate':mth(pattern,datepattern)})
                     return res
 
         return res
@@ -353,6 +382,17 @@ class SOFTextExtractor:
             seconddate = self.monthToNum(dateparts[0])
         return datetime.datetime(day=firstdate, month=seconddate, year=thirddate)
 
+    def num_date_parse(self, datestring, datepattern):
+        dateparts = re.split('[^a-zA-Z0-9]+', datestring)
+        thirddate = int(dateparts[2])
+        if datepattern['type'].lower() == 'dmy':
+            firstdate = int(dateparts[0])
+            seconddate = int(dateparts[1])
+        else:
+            firstdate = int(dateparts[1])
+            seconddate = int(dateparts[0])
+        return datetime.datetime(day=firstdate, month=seconddate, year=thirddate)
+
 
     def dd_mmmm_yyyy(self, result, delimiter):
         if len(delimiter) == 2:
@@ -397,12 +437,13 @@ class SOFPDFExtractor:
 
 
 class SOFEvent:
-    def __init__(self, id, type=None, description=None, time_from=None, time_to=None, date_from=None, date_to=None):
+    def __init__(self, id, type=None, description=None, time_from=None, time_to=None, date_from=None, date_to=None, summary=False):
         self.id = id
         self.type = type
         self.startdatetime = date_from
         self.description = description
         self.enddatetime = time_to
+        self.summary = summary
 
     def __eq__(self, other):
         if (isinstance(other, SOFEvent)):
@@ -414,9 +455,10 @@ class SOFEvent:
         
 
 class SOF:
-    def __init__(self, id, sofs=None):
+    def __init__(self, id, sofs=[], summary_sofs=[]):
         self.id = id
         self.sofs = sofs
+        self.summary_sofs = summary_sofs
 
     def add(self, sof):
         checked = False
